@@ -12,7 +12,7 @@ import os
 import six
 import websocket
 
-from rook.exceptions import RookCommunicationException, RookInvalidToken, RookDependencyConflict, RookMessageSizeExceeded
+from rook.exceptions import RookCommunicationException, RookInvalidToken, RookDependencyConflict, RookMessageSizeExceeded, RookMissingToken
 import rook.com_ws.socketpair_compat  # do not remove - adds socket.socketpair on Windows lgtm[py/unused-import]
 
 try:
@@ -169,8 +169,11 @@ class AgentCom(object):
                     self._register_agent(self.debug)
 
                 except websocket.WebSocketBadStatusException as e:
-                    if not self._token_valid and e.status_code == 403:  # invalid token
-                        self._connection_error = RookInvalidToken(self._token)
+                    if not self._token_valid and e.status_code == 403:# invalid token
+                        if self._token is None:
+                            self._connection_error = RookMissingToken()
+                        else:
+                            self._connection_error = RookInvalidToken(self._token)
                         self._ready_event.set()
 
                         logger.error('Connection failed; %s', self._connection_error.get_message())
@@ -211,7 +214,10 @@ class AgentCom(object):
                 except Exception:
                     logger.debug("Failed to signal stop", exc_info=1)
                 finally:
-                    stop_socket_incoming.close()
+                    try:
+                        stop_socket_incoming.close()
+                    except:  # lgtm[py/catch-base-exception]
+                        pass
 
             def signal_stop_outgoing_thread():
                 # Logging is not safe here, interpreter might be shutting down
@@ -256,12 +262,15 @@ class AgentCom(object):
 
         events = poller.poll(AgentComConfiguration.PING_TIMEOUT * 1000)
 
-        for fd, flag in events:
-            if fd == stop_socket.fileno():
-                return True  # signaled to stop
-            elif fd == self._connection.fileno() and flag \
-                    and flag & exception_flags:  # Checking these flags explicitly (ignore input data)
-                return True
+        try:
+            for fd, flag in events:
+                if fd == stop_socket.fileno():
+                    return True  # signaled to stop
+                elif fd == self._connection.fileno() and flag \
+                        and flag & exception_flags:  # Checking these flags explicitly (ignore input data)
+                    return True
+        except AttributeError:  # happens when the socket is already None (and fileno() will fail)
+            return True  # Should stop
 
         if len(events) == 0:
             logger.debug("Incoming thread - ping timeout")
@@ -312,9 +321,11 @@ class AgentCom(object):
                 except (socket.error, websocket.WebSocketConnectionClosedException):
                     logger.debug("Incoming thread - socket disconnected")
                     break
-        except:
-            logger.exception("Incoming thread failed")
-
+        except: # lgtm[py/catch-base-exception]
+            try:
+                logger.exception("Incoming thread failed")
+            except:  # lgtm[py/catch-base-exception]
+                pass
         finally:
             on_exit()
 
@@ -351,8 +362,10 @@ class AgentCom(object):
                         self._queue.put(msg)
                     break
         except:  # lgtm[py/catch-base-exception]
-            logger.exception("Outgoing thread failed")
-
+            try:
+                logger.exception("Outgoing thread failed")
+            except:  # lgtm[py/catch-base-exception]
+                pass
         finally:
             on_exit()
 
@@ -378,6 +391,11 @@ class AgentCom(object):
             host = re.sub(':\d+$', '', urlparse(url).netloc)
         else:
             host = None
+        
+        connect_kwargs['sslopt'] = dict()
+
+        if os.environ.get('ROOKOUT_SKIP_SSL_VERIFY') == '1':
+            connect_kwargs['sslopt']['cert_reqs']=ssl.CERT_NONE
 
         try:
             # connect using system certificates
@@ -389,7 +407,7 @@ class AgentCom(object):
         except (ssl.SSLError, getattr(ssl, 'CertificateError', None)):
             # connect using certifi certificate bundle
             # (Python 2.7.15+ from python.org on macOS rejects our CA, see RK-3383)
-            connect_kwargs['sslopt'] = dict(ca_certs=certifi.where())
+            connect_kwargs['sslopt']['ca_certs']=certifi.where()
             logger.debug("Got SSL error when connecting using system CA cert store, falling back to certifi")
             conn = websocket.create_connection(*connect_args, **connect_kwargs)
         conn.settimeout(None)
