@@ -10,7 +10,7 @@ import websocket
 
 from rook.com_ws.flush_messages_event import FlushMessagesEvent
 from rook.com_ws.singlethread.network_event_loop import NetworkEventLoop
-from rook.exceptions import RookCommunicationException, RookInvalidToken, RookDependencyConflict, RookMessageSizeExceeded
+from rook.exceptions import RookCommunicationException, RookInvalidToken, RookDependencyConflict, RookMessageSizeExceeded, RookMissingToken
 import rook.com_ws.socketpair_compat  # do not remove - adds socket.socketpair on Windows lgtm[py/unused-import]
 
 
@@ -165,8 +165,11 @@ class AgentCom(object):
                     self._register_agent(self.debug)
 
                 except websocket.WebSocketBadStatusException as e:
-                    if not self._token_valid and e.status_code == 403:  # invalid token
-                        self._connection_error = RookInvalidToken(self._token)
+                    if not self._token_valid and e.status_code == 403:# invalid token
+                        if self._token is None:
+                            self._connection_error = RookMissingToken()
+                        else:
+                            self._connection_error = RookInvalidToken(self._token)
                         self._ready_event.set()
 
                         logger.error('Connection failed; %s', self._connection_error.get_message())
@@ -227,6 +230,11 @@ class AgentCom(object):
         else:
             host = None
 
+        connect_kwargs['sslopt'] = dict()
+
+        if os.environ.get('ROOKOUT_SKIP_SSL_VERIFY') == '1':
+            connect_kwargs['sslopt']['cert_reqs']=ssl.CERT_NONE
+
         try:
             # connect using system certificates
             conn = websocket.create_connection(*connect_args, host=host, **connect_kwargs)
@@ -237,7 +245,7 @@ class AgentCom(object):
         except (ssl.SSLError, getattr(ssl, 'CertificateError', None)):
             # connect using certifi certificate bundle
             # (Python 2.7.15+ from python.org on macOS rejects our CA, see RK-3383)
-            connect_kwargs['sslopt'] = dict(ca_certs=certifi.where())
+            connect_kwargs['sslopt']['ca_certs']=certifi.where()
             logger.debug("Got SSL error when connecting using system CA cert store, falling back to certifi")
             conn = websocket.create_connection(*connect_args, **connect_kwargs)
         # just in case there's a bug and we get stuck - timeout should never be hit since we always use select()
