@@ -65,3 +65,7 @@ class HttpServerServiceConfig(object):
 class GitConfig(object):
     GIT_COMMIT = None
     GIT_ORIGIN = None
+
+
+class ShutdownConfig(object):
+    IS_SHUTTING_DOWN = False
