@@ -176,6 +176,9 @@ class PythonObjectNamespace(Namespace):
     def __hash__(self):
         return hash(self.obj)
 
+    def __eq__(self, other):
+        return type(self) == other and self.obj == other.obj
+
     def __nonzero__(self):
         return bool(self.obj)
 
