@@ -36,10 +36,10 @@ class TracebackNamespace(Namespace):
         for i in range(self._depth):
             frame = variant_pb2.Variant.CodeObject()
 
-            frame.filename = current_frame.filename().obj
-            frame.name = current_frame.function().obj
-            frame.lineno = current_frame.line().obj
-            frame.module = current_frame.module().obj
+            frame.filename = current_frame.filename().obj if current_frame.filename().obj is not None else "unavailable"
+            frame.name = current_frame.function().obj if current_frame.function().obj is not None else "unavailable"
+            frame.lineno = current_frame.line().obj if current_frame.line().obj is not None else 0
+            frame.module = current_frame.module().obj if current_frame.module().obj is not None else "unavailable"
 
             variant.traceback.locations.append(frame)
 
