@@ -1,5 +1,4 @@
 import threading
-import six
 
 
 class ExceptionCapturingLocationService(object):
@@ -21,7 +20,7 @@ class ExceptionCapturingLocationService(object):
         with self._lock:
             try:
                 self._aug_ids.remove(aug_id)
-            except ValueError:
+            except ValueError: # if value is not the array then there's nothing to do here
                 pass
 
     def clear_augs(self):
