@@ -378,14 +378,31 @@ static OpcodeMutableStatus IsOpcodeMutable(const uint8 opcode) {
     case FORMAT_VALUE:
     case BUILD_CONST_KEY_MAP:
     case BUILD_STRING:
+#if PY_VERSION_HEX < 0x03090000
     case BUILD_TUPLE_UNPACK_WITH_CALL:
+#endif
 #endif
     case LOAD_CLASSDEREF:
+#if PY_VERSION_HEX < 0x03090000
     case BUILD_LIST_UNPACK:
     case BUILD_MAP_UNPACK:
     case BUILD_MAP_UNPACK_WITH_CALL:
     case BUILD_TUPLE_UNPACK:
     case BUILD_SET_UNPACK:
+#endif
+#if PY_VERSION_HEX >= 0x03090000
+    case RERAISE:
+    case WITH_EXCEPT_START:
+    case LOAD_ASSERTION_ERROR:
+    case LIST_TO_TUPLE:
+    case LIST_EXTEND:
+    case DICT_UPDATE:
+    case SET_UPDATE:
+    case DICT_MERGE:
+    case CONTAINS_OP:
+    case IS_OP:
+    case JUMP_IF_NOT_EXC_MATCH:
+#endif
 #if PY_VERSION_HEX >= 0x03070000
     // Added in Python 3.7.
     case LOAD_METHOD:
@@ -435,7 +452,9 @@ static OpcodeMutableStatus IsOpcodeMutable(const uint8 opcode) {
     case STORE_DEREF:
     // TODO(xinghuadou): allow exception handling
     case RAISE_VARARGS:
+#if PY_VERSION_HEX < 0x03090000
     case END_FINALLY:
+#endif
     case SETUP_WITH:
     // TODO(xinghuadou): allow closures
     case LOAD_CLOSURE:
@@ -445,8 +464,10 @@ static OpcodeMutableStatus IsOpcodeMutable(const uint8 opcode) {
     case BEFORE_ASYNC_WITH:
     case LOAD_BUILD_CLASS:
     case GET_AWAITABLE:
+#if PY_VERSION_HEX < 0x03090000
     case WITH_CLEANUP_START:
     case WITH_CLEANUP_FINISH:
+#endif
 #if PY_VERSION_HEX >= 0x03060000
     case SETUP_ANNOTATIONS:
 #endif
